==> quanyi-center-api-0.0.49-20231220.024847-7-sources.jar: cn/com/duiba/quanyi/center/api/dto/contract/ContractDto.java <==
package cn.com.duiba.quanyi.center.api.dto.contract;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 合同表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@Data
public class ContractDto implements Serializable {

    private static final long serialVersionUID = 4839906531083624544L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 合同名称
     */
    private String contractName;

    /**
     * 合作客户主键, tb_partner.id
     */
    private Long partnerId;

    /**
     * 合同编号
     */
    private String contractCode;

    /**
     * 合同文件地址
     */
    private String contractFile;

    /**
     * 消耗类型, 1-框架，2-预算
     *
     * @see cn.com.duiba.quanyi.center.api.enums.contract.ContractConsumeTypeEnum
     */
    private Integer consumeType;

    /**
     * 消耗上限
     */
    private String consumeDesc;

    /**
     * 合作开始时间
     */
    private Date startTime;

    /**
     * 合作结束时间
     */
    private Date endTime;

    /**
     * 合同运营，多个以英文逗号分隔
     */
    private String contractOperations;

    /**
     * 合同商务，多个以英文逗号分隔
     */
    private String contractCommerce;

    /**
     * 是否逻辑删除, 0-未删除, 1-已删除
     *
     * @see cn.com.duiba.quanyi.center.api.enums.BooleanEnum
     */
    private Integer logicDelete;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;


    /**
     * 创建人id
     */
    private Long createPersonId;


    /**
     * 创建人名称
     */
    private String createPersonName;


}

==> quanyi-center-api-1.0.57-sources.jar: cn/com/duiba/quanyi/center/api/dto/contract/ContractDto.java <==
package cn.com.duiba.quanyi.center.api.dto.contract;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 合同表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@Data
public class ContractDto implements Serializable {

    private static final long serialVersionUID = 4839906531083624544L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 合同名称
     */
    private String contractName;

    /**
     * 合作客户主键, tb_partner.id
     */
    private Long partnerId;

    /**
     * 合同编号
     */
    private String contractCode;

    /**
     * 合同文件地址
     */
    private String contractFile;

    /**
     * 消耗类型, 1-框架，2-预算
     *
     * @see cn.com.duiba.quanyi.center.api.enums.contract.ContractConsumeTypeEnum
     */
    private Integer consumeType;

    /**
     * 消耗上限
     */
    private String consumeDesc;

    /**
     * 合作开始时间
     */
    private Date startTime;

    /**
     * 合作结束时间
     */
    private Date endTime;

    /**
     * 合同运营，多个以英文逗号分隔
     */
    private String contractOperations;

    /**
     * 合同商务，多个以英文逗号分隔
     */
    private String contractCommerce;

    /**
     * 是否逻辑删除, 0-未删除, 1-已删除
     *
     * @see cn.com.duiba.quanyi.center.api.enums.BooleanEnum
     */
    private Integer logicDelete;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;
    /**
     * 创建人id
     */
    private Long createOperatorId;
    /**
     * 创建人名称
     */
    private String createOperatorName;
}
